@@ -108,7 +108,7 @@ typedef struct ResultBuffer ResultBuffer;
 static inline void	ResultClear(ResultBuffer *r);
 static inline void	ResultInit(ResultBuffer *r);
 static inline int	ResultEmpty(ResultBuffer *r);
-static inline int	ResultCopy(ResultBuffer *r, unsigned char *buf,
+static inline size_t	ResultCopy(ResultBuffer *r, unsigned char *buf,
 			    size_t toRead);
 static inline void	ResultAdd(ResultBuffer *r, unsigned char *buf,
 			    size_t toWrite);
@@ -271,7 +271,7 @@ TclChannelTransform(
 	return TCL_ERROR;
     }
 
-    if (TCL_OK != Tcl_ListObjLength(interp, cmdObjPtr, &objc)) {
+    if (TCL_OK != TclListObjLength(interp, cmdObjPtr, &objc)) {
 	Tcl_SetObjResult(interp,
 		Tcl_NewStringObj("-command value is not a list", -1));
 	return TCL_ERROR;
@@ -406,7 +406,7 @@ ExecuteCallback(
 
     /*
      * Use a byte-array to prevent the misinterpretation of binary data coming
-     * through as UTF while at the tcl level.
+     * through as Utf while at the tcl level.
      */
 
     Tcl_ListObjAppendElement(NULL, command, Tcl_NewByteArrayObj(buf, bufLen));
@@ -414,7 +414,7 @@ ExecuteCallback(
     /*
      * Step 2, execute the command at the global level of the interpreter used
      * to create the transformation. Destroy the command afterward. If an
-     * error occured and the current interpreter is defined and not equal to
+     * error occurred and the current interpreter is defined and not equal to
      * the interpreter for the callback, then copy the error message into
      * current interpreter. Don't copy if in preservation mode.
      */
@@ -560,7 +560,7 @@ TransformCloseProc(
      * Now flush data waiting in internal buffers to output and input. The
      * input must be done despite the fact that there is no real receiver for
      * it anymore. But the scripts might have sideeffects other parts of the
-     * system rely on (f.e. signaling the close to interested parties).
+     * system rely on (f.e. signalling the close to interested parties).
      */
 
     PreserveData(dataPtr);
@@ -1097,7 +1097,7 @@ TransformWatchProc(
     Tcl_Channel downChan;
 
     /*
-     * The caller expressed interest in events occuring for this channel. We
+     * The caller expressed interest in events occurring for this channel. We
      * are forwarding the call to the underlying channel now.
      */
 
@@ -1204,12 +1204,12 @@ static int
 TransformNotifyProc(
     ClientData clientData,	/* The state of the notified
 				 * transformation. */
-    int mask)			/* The mask of occuring events. */
+    int mask)			/* The mask of occurring events. */
 {
     TransformChannelData *dataPtr = (TransformChannelData *)clientData;
 
     /*
-     * An event occured in the underlying channel. This transformation doesn't
+     * An event occurred in the underlying channel. This transformation doesn't
      * process such events thus returns the incoming mask unchanged.
      */
 
@@ -1299,7 +1299,7 @@ ResultClear(
  * ResultInit --
  *
  *	Initializes the specified buffer structure. The structure will contain
- *	valid information for an emtpy buffer.
+ *	valid information for an empty buffer.
  *
  * Side effects:
  *	See above.
@@ -1361,13 +1361,13 @@ ResultEmpty(
  *----------------------------------------------------------------------
  */
 
-static inline int
+static inline size_t
 ResultCopy(
     ResultBuffer *r,		/* The buffer to read from. */
     unsigned char *buf,		/* The buffer to copy into. */
     size_t toRead)		/* Number of requested bytes. */
 {
-    if (r->used == 0) {
+    if (ResultEmpty(r)) {
 	/*
 	 * Nothing to copy in the case of an empty buffer.
 	 */
@@ -1424,7 +1424,7 @@ ResultAdd(
     unsigned char *buf,		/* The buffer to read from. */
     size_t toWrite)		/* The number of bytes in 'buf'. */
 {
-    if (r->used + toWrite > r->allocated) {
+    if ((r->used + toWrite + 1) > r->allocated) {
 	/*
 	 * Extension of the internal buffer is required.
 	 */
