@@ -132,11 +132,11 @@ static const Tcl_MethodType classConstructor = {
 };
 
 /*
- * Scripted parts of TclOO. First, the master script (cannot be outside this
+ * Scripted parts of TclOO. First, the main script (cannot be outside this
  * file).
  */
 
-static const char *initScript =
+static const char initScript[] =
 "package ifneeded TclOO " TCLOO_PATCHLEVEL " {# Already present, OK?};"
 "namespace eval ::oo { variable version " TCLOO_VERSION " };"
 "namespace eval ::oo { variable patchlevel " TCLOO_PATCHLEVEL " };";
@@ -276,7 +276,7 @@ TclOOInit(
     }
 
     return Tcl_PkgProvideEx(interp, "TclOO", TCLOO_PATCHLEVEL,
-	    (ClientData) &tclOOStubs);
+	    &tclOOStubs);
 }
 
 /*
@@ -398,11 +398,12 @@ InitFoundation(
      */
 
     fakeCls.thisPtr = &fakeObject;
+    fakeObject.refCount = 0; /* Do not increment an uninitialized value. */
 
     fPtr->objectCls = TclOOAllocClass(interp,
 	    AllocObject(interp, "object", (Namespace *)fPtr->ooNs, NULL));
     /*
-     * Corresponding TclOODecrRefCount in KillFoudation.
+     * Corresponding TclOODecrRefCount in KillFoundation.
      */
 
     AddRef(fPtr->objectCls->thisPtr);
@@ -428,7 +429,7 @@ InitFoundation(
 	    AllocObject(interp, "class", (Namespace *)fPtr->ooNs, NULL));
 
     /*
-     * Corresponding TclOODecrRefCount in KillFoudation.
+     * Corresponding TclOODecrRefCount in KillFoundation.
      */
 
     AddRef(fPtr->classCls->thisPtr);
@@ -661,7 +662,7 @@ AllocObject(
     while (1) {
 	char objName[10 + TCL_INTEGER_SPACE];
 
-	sprintf(objName, "::oo::Obj%d", ++fPtr->tsdPtr->nsCount);
+	snprintf(objName, sizeof(objName), "::oo::Obj%d", ++fPtr->tsdPtr->nsCount);
 	oPtr->namespacePtr = Tcl_CreateNamespace(interp, objName, oPtr, NULL);
 	if (oPtr->namespacePtr != NULL) {
 	    creationEpoch = fPtr->tsdPtr->nsCount;
@@ -797,7 +798,7 @@ MyDeleted(
     ClientData clientData)	/* Reference to the object whose [my] has been
 				 * squelched. */
 {
-    register Object *oPtr = clientData;
+    Object *oPtr = clientData;
 
     oPtr->myCommand = NULL;
 }
@@ -1105,7 +1106,7 @@ ObjectNamespaceDeleted(
 
     /*
      * One rule for the teardown routines is that if an object is in the
-     * process of being deleted, nothing else may modify its bookeeping
+     * process of being deleted, nothing else may modify its bookkeeping
      * records.  This is the flag that
      */
     oPtr->flags |= OBJECT_DESTRUCTING;
@@ -1157,7 +1158,7 @@ ObjectNamespaceDeleted(
     if (((Command *) oPtr->command)->flags && CMD_IS_DELETED) {
 	/*
 	 * Something has already started the command deletion process. We can
-	 * go ahead and clean up the the namespace,
+	 * go ahead and clean up the namespace,
 	 */
     } else {
 	/*
@@ -1632,7 +1633,7 @@ Tcl_NewObjectInstance(
     int skip)			/* Number of arguments to _not_ pass to the
 				 * constructor. */
 {
-    register Class *classPtr = (Class *) cls;
+    Class *classPtr = (Class *) cls;
     Object *oPtr;
     ClientData clientData[4];
 
@@ -1700,7 +1701,7 @@ TclNRNewObjectInstance(
     Tcl_Object *objectPtr)	/* Place to write the object reference upon
 				 * successful allocation. */
 {
-    register Class *classPtr = (Class *) cls;
+    Class *classPtr = (Class *) cls;
     CallContext *contextPtr;
     Tcl_InterpState state;
     Object *oPtr;
@@ -2558,7 +2559,7 @@ TclOOObjectCmdCore(
 
     methodNamePtr = objv[1];
     if (oPtr->mapMethodNameProc != NULL) {
-	register Class **startClsPtr = &startCls;
+	Class **startClsPtr = &startCls;
 	Tcl_Obj *mappedMethodName = Tcl_DuplicateObj(methodNamePtr);
 
 	result = oPtr->mapMethodNameProc(interp, (Tcl_Object) oPtr,
@@ -2615,7 +2616,7 @@ TclOOObjectCmdCore(
     if (startCls != NULL) {
 	for (; contextPtr->index < contextPtr->callPtr->numChain;
 		contextPtr->index++) {
-	    register struct MInvoke *miPtr =
+	    struct MInvoke *miPtr =
 		    &contextPtr->callPtr->chain[contextPtr->index];
 
 	    if (miPtr->isFilter) {
@@ -2753,7 +2754,7 @@ TclNRObjectContextInvokeNext(
     Tcl_Obj *const *objv,
     int skip)
 {
-    register CallContext *contextPtr = (CallContext *) context;
+    CallContext *contextPtr = (CallContext *) context;
 
     if (contextPtr->index + 1 >= contextPtr->callPtr->numChain) {
 	/*
@@ -2925,7 +2926,7 @@ TclOOObjectName(
     if (oPtr->cachedNameObj) {
 	return oPtr->cachedNameObj;
     }
-    namePtr = Tcl_NewObj();
+    TclNewObj(namePtr);
     Tcl_GetCommandFullName(interp, oPtr->command, namePtr);
     Tcl_IncrRefCount(namePtr);
     oPtr->cachedNameObj = namePtr;
