@@ -676,11 +676,11 @@ Tcl_GetMemoryInfo(
 	if (cachePtr == sharedPtr) {
 	    Tcl_DStringAppendElement(dsPtr, "shared");
 	} else {
-	    sprintf(buf, "thread%p", cachePtr->owner);
+	    snprintf(buf, sizeof(buf), "thread%p", cachePtr->owner);
 	    Tcl_DStringAppendElement(dsPtr, buf);
 	}
 	for (n = 0; n < NBUCKETS; ++n) {
-	    sprintf(buf, "%lu %ld %ld %ld %ld %ld %ld",
+	    snprintf(buf, sizeof(buf), "%lu %ld %ld %ld %ld %ld %ld",
 		    (unsigned long) bucketInfo[n].blockSize,
 		    cachePtr->buckets[n].numFree,
 		    cachePtr->buckets[n].numRemoves,
@@ -973,7 +973,7 @@ GetBlocks(
     int n;
 
     /*
-     * First, atttempt to move blocks from the shared cache. Note the
+     * First, attempt to move blocks from the shared cache. Note the
      * potentially dirty read of numFree before acquiring the lock which is a
      * slight performance enhancement. The value is verified after the lock is
      * actually acquired.
