@@ -1,7 +1,7 @@
 /*
  * tclUnixFCmd.c
  *
- *	This file implements the unix specific portion of file manipulation
+ *	This file implements the Unix specific portion of file manipulation
  *	subcommands of the "file" command. All filename arguments should
  *	already be translated to native format.
  *
@@ -350,7 +350,7 @@ DoRenameFile(
     }
 
     /*
-     * IRIX returns EIO when you attept to move a directory into itself. We
+     * IRIX returns EIO when you attempt to move a directory into itself. We
      * just map EIO to EINVAL get the right message on SGI. Most platforms
      * don't return EIO except in really strange cases.
      */
@@ -740,7 +740,7 @@ DoCreateDirectory(
  *
  *	Recursively copies a directory. The target directory dst must not
  *	already exist. Note that this function does not merge two directory
- *	hierarchies, even if the target directory is an an empty directory.
+ *	hierarchies, even if the target directory is an empty directory.
  *
  * Results:
  *	If the directory was successfully copied, returns TCL_OK. Otherwise
@@ -1369,7 +1369,7 @@ GetGroupAttribute(
     groupPtr = TclpGetGrGid(statBuf.st_gid);
 
     if (groupPtr == NULL) {
-	*attributePtrPtr = Tcl_NewIntObj((int) statBuf.st_gid);
+	TclNewIntObj(*attributePtrPtr, (int) statBuf.st_gid);
     } else {
 	Tcl_DString ds;
 	const char *utf;
@@ -1423,7 +1423,7 @@ GetOwnerAttribute(
     pwPtr = TclpGetPwUid(statBuf.st_uid);
 
     if (pwPtr == NULL) {
-	*attributePtrPtr = Tcl_NewIntObj((int) statBuf.st_uid);
+	TclNewIntObj(*attributePtrPtr, (int) statBuf.st_uid);
     } else {
 	Tcl_DString ds;
 
@@ -1841,7 +1841,7 @@ GetModeFromPermString(
 		/* who */
 		switch (*(modeStringPtr+n+i)) {
 		case 'u':
-		    who |= 0x9c0;
+		    who |= 0x9C0;
 		    continue;
 		case 'g':
 		    who |= 0x438;
@@ -1850,13 +1850,13 @@ GetModeFromPermString(
 		    who |= 0x207;
 		    continue;
 		case 'a':
-		    who |= 0xfff;
+		    who |= 0xFFF;
 		    continue;
 		}
 	    }
 	    who_found = 1;
 	    if (who == 0) {
-		who = 0xfff;
+		who = 0xFFF;
 	    }
 	    if (!op_found) {
 		/* op */
@@ -1889,7 +1889,7 @@ GetModeFromPermString(
 		what |= 0x49;
 		continue;
 	    case 's':
-		what |= 0xc00;
+		what |= 0xC00;
 		continue;
 	    case 't':
 		what |= 0x200;
@@ -2341,7 +2341,7 @@ GetUnixFileAttributes(
 	return TCL_ERROR;
     }
 
-    *attributePtrPtr = Tcl_NewIntObj((fileAttributes&attributeArray[objIndex])!=0);
+    TclNewIntObj(*attributePtrPtr, (fileAttributes&attributeArray[objIndex])!=0);
 
     return TCL_OK;
 }
