@@ -574,7 +574,7 @@ Tcl_MutexLock(
 	 */
 
 	if (*mutexPtr == NULL) {
-	    csPtr = ckalloc(sizeof(CRITICAL_SECTION));
+	    csPtr = (CRITICAL_SECTION *)ckalloc(sizeof(CRITICAL_SECTION));
 	    InitializeCriticalSection(csPtr);
 	    *mutexPtr = (Tcl_Mutex)csPtr;
 	    TclRememberMutex(mutexPtr);
@@ -717,7 +717,7 @@ Tcl_ConditionWait(
 	 */
 
 	if (*condPtr == NULL) {
-	    winCondPtr = ckalloc(sizeof(WinCondition));
+	    winCondPtr = (WinCondition *)ckalloc(sizeof(WinCondition));
 	    InitializeCriticalSection(&winCondPtr->condLock);
 	    winCondPtr->firstPtr = NULL;
 	    winCondPtr->lastPtr = NULL;
@@ -783,9 +783,9 @@ Tcl_ConditionWait(
 	    timeout = 0;
 	} else {
 	    /*
-	     * When dequeuing, we can leave the tsdPtr->nextPtr and
+	     * When dequeueing, we can leave the tsdPtr->nextPtr and
 	     * tsdPtr->prevPtr with dangling pointers because they are
-	     * reinitialilzed w/out reading them when the thread is enqueued
+	     * reinitialized w/out reading them when the thread is enqueued
 	     * later.
 	     */
 
@@ -946,7 +946,7 @@ TclpNewAllocMutex(void)
 {
     struct allocMutex *lockPtr;
 
-    lockPtr = malloc(sizeof(struct allocMutex));
+    lockPtr = (struct allocMutex *)malloc(sizeof(struct allocMutex));
     if (lockPtr == NULL) {
 	Tcl_Panic("could not allocate lock");
     }
@@ -1045,7 +1045,7 @@ TclpThreadCreateKey(void)
 {
     DWORD *key;
 
-    key = TclpSysAlloc(sizeof *key, 0);
+    key = (DWORD *)TclpSysAlloc(sizeof *key, 0);
     if (key == NULL) {
 	Tcl_Panic("unable to allocate thread key!");
     }
@@ -1063,7 +1063,7 @@ void
 TclpThreadDeleteKey(
     void *keyPtr)
 {
-    DWORD *key = keyPtr;
+    DWORD *key = (DWORD *)keyPtr;
 
     if (!TlsFree(*key)) {
 	Tcl_Panic("unable to delete key");
@@ -1077,7 +1077,7 @@ TclpThreadSetGlobalTSD(
     void *tsdKeyPtr,
     void *ptr)
 {
-    DWORD *key = tsdKeyPtr;
+    DWORD *key = (DWORD *)tsdKeyPtr;
 
     if (!TlsSetValue(*key, ptr)) {
 	Tcl_Panic("unable to set global TSD value");
@@ -1088,7 +1088,7 @@ void *
 TclpThreadGetGlobalTSD(
     void *tsdKeyPtr)
 {
-    DWORD *key = tsdKeyPtr;
+    DWORD *key = (DWORD *)tsdKeyPtr;
 
     return TlsGetValue(*key);
 }
